@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+from decimal import Decimal
 import urllib
 from pagador import settings
 from pagador.acesso.externo import FormatoDeEnvio
@@ -161,6 +162,28 @@ class Registro(RegistroBase):
                 return None
         return self._pedido
 
+    # FIXME: rever isso ao refatorar o sistema de pedido
+    @property
+    def valor_envio(self):
+        valor_envio = self.pedido.valor_envio or Decimal("0.00")
+        valor_desconto = self.pedido.valor_desconto or Decimal("0.00")
+        if valor_envio == valor_desconto:
+            return Decimal("0.00")
+        return valor_envio
+
+    @property
+    def valor_desconto(self):
+        valor_envio = self.pedido.valor_envio or Decimal("0.00")
+        valor_desconto = self.pedido.valor_desconto or Decimal("0.00")
+        if valor_envio == valor_desconto:
+            return Decimal("0.00")
+        return valor_desconto
+
+    @property
+    def valor_subtotal(self):
+        valor_subtotal = self.pedido.valor_subtotal or Decimal("0.00")
+        return valor_subtotal - self.valor_desconto
+
     def gerar_dados_de_envio(self):
         notification_url = settings.PAYPAL_NOTIFICATION_URL.format(self.pedido.conta_id)
         parametros = ParametrosPayPal("paypal", id=self.pedido.conta_id)
@@ -181,29 +204,36 @@ class Registro(RegistroBase):
 
             paymentrequest_0_paymentaction='SALE',
             paymentrequest_0_notifyurl=notification_url,
-            paymentrequest_0_amt=self.formatador.formata_decimal(self.pedido.valor_total),
-            paymentrequest_0_shippingamt=self.formatador.formata_decimal(self.pedido.valor_total - self.pedido.valor_subtotal),
+
+            paymentrequest_0_shippingamt=self.formatador.formata_decimal(self.valor_envio),
+            paymentrequest_0_itemamt=self.formatador.formata_decimal(self.valor_subtotal),
+
             paymentrequest_0_currencycode="BRL",
-            paymentrequest_0_itemamt=self.formatador.formata_decimal(self.pedido.valor_subtotal),
             paymentrequest_0_invnum=self.pedido.numero,
 
-            paymentrequest_0_shiptoname=unicode(self.pedido.endereco_entrega.nome),
+            paymentrequest_0_shiptoname=self.formatador.trata_unicode_com_limite(self.pedido.endereco_entrega.nome),
             paymentrequest_0_shiptostreet=u"{}, {} {}".format(self.pedido.endereco_entrega.endereco, self.pedido.endereco_entrega.numero, self.pedido.endereco_entrega.complemento),
-            paymentrequest_0_shiptostreet2=unicode(self.pedido.endereco_entrega.bairro),
-            paymentrequest_0_shiptocity=unicode(self.pedido.endereco_entrega.cidade),
+            paymentrequest_0_shiptostreet2=self.formatador.trata_unicode_com_limite(self.pedido.endereco_entrega.bairro),
+            paymentrequest_0_shiptocity=self.formatador.trata_unicode_com_limite(self.pedido.endereco_entrega.cidade),
             paymentrequest_0_shiptostate=self.pedido.endereco_entrega.estado,
             paymentrequest_0_shiptozip=self.pedido.endereco_entrega.cep,
             paymentrequest_0_shiptocountrycode="BR",
             paymentrequest_0_shiptophonenum=self.pedido.cliente.telefone_principal
         )
+        indice_final = 0
         for indice, item in enumerate(self.pedido.itens.all()):
-            self.define_valor_de_atributo_de_item(request_payment, "NAME", indice, unicode(item.nome[:127]))
+            self.define_valor_de_atributo_de_item(request_payment, "NAME", indice, self.formatador.trata_unicode_com_limite(item.nome, 127))
             self.define_valor_de_atributo_de_item(request_payment, "DESC", indice, "")
             self.define_valor_de_atributo_de_item(request_payment, "AMT", indice, self.formatador.formata_decimal(item.preco_venda))
             self.define_valor_de_atributo_de_item(request_payment, "QTY", indice, self.formatador.formata_decimal(item.quantidade))
-            self.define_valor_de_atributo_de_item(request_payment, "NUMBER", indice, unicode(item.sku[:127]))
-            self.define_valor_de_atributo_de_item(request_payment, "ITEMURL", indice, item.produto.get_absolute_url())
-
+            self.define_valor_de_atributo_de_item(request_payment, "NUMBER", indice, self.formatador.trata_unicode_com_limite(item.sku, 127))
+            self.define_valor_de_atributo_de_item(request_payment, "ITEMURL", indice, item.produto.get_absolute_url() or "")
+            indice_final = indice
+        indice_final += 1
+        if self.valor_desconto:
+            self.define_valor_de_atributo_de_item(request_payment, "NAME", indice_final, "Desconto")
+            self.define_valor_de_atributo_de_item(request_payment, "AMT", indice_final, self.formatador.formata_decimal((self.valor_desconto * -1)))
+            self.define_valor_de_atributo_de_item(request_payment, "QTY", indice_final, 1)
         return request_payment.to_dict()
 
     def define_valor_de_atributo_de_item(self, request, atributo, indice, valor):
